@@ -48,7 +48,7 @@ import OSLog
     // This does lead to long load times when a file provider domain is initially configured.
     // We can instead do a fast enumeration where we only scan folders as the user navigates through
     // them, thereby avoiding this issue; the trade-off is that we will be unable to detect
-    // materialised file moves to unexplored folders, therefore deleting the item when we could have
+    // materialized file moves to unexplored folders, therefore deleting the item when we could have
     // just moved it instead.
     //
     // Since it's not desirable to cancel a long recursive enumeration half-way through, we do the
@@ -90,6 +90,8 @@ import OSLog
     }
 
     func insertSyncAction(_ actionId: UUID) {
+        logger.debug("Inserting synchronization action.", [.item: actionId])
+
         actionsLock.lock()
         let oldActions = syncActions
         syncActions.insert(actionId)
@@ -98,6 +100,8 @@ import OSLog
     }
 
     func insertErrorAction(_ actionId: UUID) {
+        logger.debug("Inserting error action.", [.item: actionId])
+
         actionsLock.lock()
         let oldActions = syncActions
         syncActions.remove(actionId)
@@ -107,6 +111,8 @@ import OSLog
     }
 
     func removeSyncAction(_ actionId: UUID) {
+        logger.debug("Removing synchronization action.", [.item: actionId])
+
         actionsLock.lock()
         let oldActions = syncActions
         syncActions.remove(actionId)
@@ -133,21 +139,15 @@ import OSLog
         }
 
         let progress = Progress()
+        
         Task {
             progress.totalUnitCount = 1
-            if let item = await Item.storedItem(
-                identifier: identifier,
-                account: ncAccount,
-                remoteInterface: ncKit,
-                dbManager: dbManager,
-                log: log
-            ) {
+
+            if let item = await Item.storedItem(identifier: identifier, account: ncAccount, remoteInterface: ncKit, dbManager: dbManager, log: log) {
                 progress.completedUnitCount = 1
                 completionHandler(item, nil)
             } else {
-                completionHandler(
-                    nil, NSError.fileProviderErrorForNonExistentItem(withIdentifier: identifier)
-                )
+                completionHandler(nil, NSError.fileProviderErrorForNonExistentItem(withIdentifier: identifier))
             }
         }
         return progress
@@ -274,11 +274,23 @@ import OSLog
                 log: log
             )
 
-            if error != nil {
-                insertErrorAction(actionId)
-                signalEnumerator(completionHandler: { _ in })
-            } else {
+            if error == nil {
                 removeSyncAction(actionId)
+            } else {
+                // Do not consider the exclusion of a lock file a synchronization error resulting in a misleading status report because exclusion is expected.
+                // Though, the exclusion error code is only available starting with macOS 13, hence this logic reads a bit more cumbersome.
+
+                if #available(macOS 13.0, *) {
+                    if isLockFileName(itemTemplate.filename), let fileProviderError = error as? NSFileProviderError, fileProviderError.code == .excludedFromSync {
+                        removeSyncAction(actionId)
+                    } else {
+                        insertErrorAction(actionId)
+                        signalEnumerator(completionHandler: { _ in })
+                    }
+                } else {
+                    insertErrorAction(actionId)
+                    signalEnumerator(completionHandler: { _ in })
+                }
             }
 
             logger.debug("Calling item creation completion handler.", [.item: item?.itemIdentifier, .name: item?.filename, .error: error])
@@ -433,14 +445,6 @@ import OSLog
             }
             
             logger.debug("Found item for identifier.", [.item: identifier, .name: item.filename])
-
-            guard config.trashDeletionEnabled || item.parentItemIdentifier != .trashContainer else {
-                logger.info("System requested deletion of item in trash, but deleting trash items is disabled. item: \(item.filename)")
-                removeSyncAction(actionId)
-                completionHandler(NSError.fileProviderErrorForRejectedDeletion(of: item))
-                return
-            }
-            
             let error = await item.delete(domain: domain, ignoredFiles: ignoredFiles, dbManager: dbManager)
             
             if error != nil {
@@ -500,7 +504,7 @@ import OSLog
         }
 
         let materialisedEnumerator = fpManager.enumeratorForMaterializedItems()
-        let materialisedObserver = MaterialisedEnumerationObserver(ncKitAccount: ncAccount.ncKitAccount, dbManager: dbManager, log: log) { _, _ in
+        let materialisedObserver = MaterializedEnumerationObserver(account: ncAccount, dbManager: dbManager, log: log) { _, _ in
             completionHandler()
         }
         let startingPage = NSFileProviderPage(NSFileProviderPage.initialPageSortedByName as Data)
