@@ -46,6 +46,7 @@ constexpr auto serverVersionC = "serverVersion";
 constexpr auto serverColorC = "serverColor";
 constexpr auto serverTextColorC = "serverTextColor";
 constexpr auto skipE2eeMetadataChecksumValidationC = "skipE2eeMetadataChecksumValidation";
+constexpr auto networkProxySettingC = "networkProxySetting";
 constexpr auto networkProxyTypeC = "networkProxyType";
 constexpr auto networkProxyHostNameC = "networkProxyHostName";
 constexpr auto networkProxyPortC = "networkProxyPort";
@@ -77,6 +78,7 @@ constexpr auto maxAccountsVersion = 13;
 constexpr auto maxAccountVersion = 13;
 
 constexpr auto serverHasValidSubscriptionC = "serverHasValidSubscription";
+constexpr auto serverDesktopEnterpriseUpdateChannelC = "desktopEnterpriseChannel";
 
 constexpr auto generalC = "General";
 }
@@ -118,6 +120,10 @@ AccountManager::AccountsRestoreResult AccountManager::restore(const bool alsoRes
     }
 #endif
 
+    if (settings->childGroups().isEmpty()) {
+        return AccountsNotFound;
+    }
+
     auto result = AccountsRestoreSuccess;
     const auto settingsChildGroups = settings->childGroups();
     for (const auto &accountId : settingsChildGroups) {
@@ -135,8 +141,8 @@ AccountManager::AccountsRestoreResult AccountManager::restore(const bool alsoRes
                 jar->restore(acc->cookieJarPath());
             }
             addAccountState(accState);
+            migrateNetworkSettings(acc, *settings);
             settings->endGroup();
-            moveNetworkSettingsFromGlobalToAccount(acc);
         } else {
             qCInfo(lcAccountManager) << "Account" << accountId << "is too new, ignoring";
             _additionalBlockedAccountIds.insert(accountId);
@@ -272,9 +278,11 @@ bool AccountManager::restoreFromLegacySettings()
                     selectedAccountIds = childGroups;
                 }
 
+                const auto legacyVersion = oCSettings->value(ConfigFile::clientVersionC, {}).toString();
+                ConfigFile().setClientPreviousVersionString(legacyVersion);
+                qCInfo(lcAccountManager) << "Migrating from" << legacyVersion;
                 qCInfo(lcAccountManager) << "Copy settings" << oCSettings->allKeys().join(", ");
                 settings = std::move(oCSettings);
-
                 ConfigFile::setDiscoveredLegacyConfigPath(configFileInfo.canonicalPath());
                 break;
             } else {
@@ -284,14 +292,41 @@ bool AccountManager::restoreFromLegacySettings()
     }
 
     ConfigFile configFile;
+    // General settings
     configFile.setVfsEnabled(settings->value(ConfigFile::isVfsEnabledC, configFile.isVfsEnabled()).toBool());
-    configFile.setLaunchOnSystemStartup(settings->value(ConfigFile::launchOnSystemStartupC, configFile.launchOnSystemStartup()).toBool());
-    configFile.setOptionalServerNotifications(settings->value(ConfigFile::optionalServerNotificationsC, configFile.optionalServerNotifications()).toBool());
-    configFile.setPromptDeleteFiles(settings->value(ConfigFile::promptDeleteC, configFile.promptDeleteFiles()).toBool());
-    configFile.setShowCallNotifications(settings->value(ConfigFile::showCallNotificationsC, configFile.showCallNotifications()).toBool());
-    configFile.setShowChatNotifications(settings->value(ConfigFile::showChatNotificationsC, configFile.showChatNotifications()).toBool());
-    configFile.setShowQuotaWarningNotifications(settings->value(ConfigFile::showQuotaWarningNotificationsC, configFile.showQuotaWarningNotifications()).toBool());
-    configFile.setShowInExplorerNavigationPane(settings->value(ConfigFile::showInExplorerNavigationPaneC, configFile.showInExplorerNavigationPane()).toBool());
+    configFile.setLaunchOnSystemStartup(settings->value(ConfigFile::launchOnSystemStartupC,
+                                                        configFile.launchOnSystemStartup()).toBool());
+    const auto useMonoIcons = settings->value(ConfigFile::monoIconsC, configFile.monoIcons()).toBool();
+    Theme::instance()->setSystrayUseMonoIcons(useMonoIcons);
+    configFile.setMonoIcons(useMonoIcons);
+    configFile.setOptionalServerNotifications(settings->value(ConfigFile::optionalServerNotificationsC,
+                                                              configFile.optionalServerNotifications()).toBool());
+    configFile.setPromptDeleteFiles(settings->value(ConfigFile::promptDeleteC,
+                                                    configFile.promptDeleteFiles()).toBool());
+    configFile.setShowCallNotifications(settings->value(ConfigFile::showCallNotificationsC,
+                                                        configFile.showCallNotifications()).toBool());
+    configFile.setShowChatNotifications(settings->value(ConfigFile::showChatNotificationsC,
+                                                        configFile.showChatNotifications()).toBool());
+    configFile.setShowInExplorerNavigationPane(settings->value(ConfigFile::showInExplorerNavigationPaneC,
+                                                               configFile.showInExplorerNavigationPane()).toBool());
+    // Advanced
+    const auto newBigFolderSizeLimit = settings->value(ConfigFile::newBigFolderSizeLimitC, configFile.newBigFolderSizeLimit().second).toLongLong();
+    const auto useNewBigFolderSizeLimit = settings->value(ConfigFile::useNewBigFolderSizeLimitC, configFile.useNewBigFolderSizeLimit()).toBool();
+    configFile.setNewBigFolderSizeLimit(useNewBigFolderSizeLimit, newBigFolderSizeLimit);
+    configFile.setNotifyExistingFoldersOverLimit(settings->value(ConfigFile::notifyExistingFoldersOverLimitC,
+                                                                 configFile.notifyExistingFoldersOverLimit()).toBool());
+    configFile.setStopSyncingExistingFoldersOverLimit(settings->value(ConfigFile::stopSyncingExistingFoldersOverLimitC,
+                                                                      configFile.stopSyncingExistingFoldersOverLimit()).toBool());
+    configFile.setConfirmExternalStorage(settings->value(ConfigFile::confirmExternalStorageC, configFile.confirmExternalStorage()).toBool());
+    configFile.setMoveToTrash(settings->value(ConfigFile::moveToTrashC, configFile.moveToTrash()).toBool());
+    // Info
+    configFile.setUpdateChannel(settings->value(ConfigFile::updateChannelC, configFile.currentUpdateChannel()).toString());
+    auto previousAppName = settings->contains(ConfigFile::legacyAppName) ? ConfigFile::legacyAppName
+                                                                         : ConfigFile::unbrandedAppName;
+    const auto updaterGroupName = QString("%1/%2").arg(previousAppName, ConfigFile::autoUpdateCheckC);
+    configFile.setAutoUpdateCheck(settings->value(updaterGroupName, configFile.autoUpdateCheck()).toBool(), {});
+
+    // Global Proxy and Network
     ClientProxy().saveProxyConfigurationFromSettings(*settings);
     configFile.setUseUploadLimit(settings->value(ConfigFile::useUploadLimitC, configFile.useUploadLimit()).toInt());
     configFile.setUploadLimit(settings->value(ConfigFile::uploadLimitC, configFile.uploadLimit()).toInt());
@@ -299,9 +334,11 @@ bool AccountManager::restoreFromLegacySettings()
     configFile.setDownloadLimit(settings->value(ConfigFile::downloadLimitC, configFile.downloadLimit()).toInt());
 
     // Try to load the single account.
+    configFile.setMigrationPhase(ConfigFile::MigrationPhase::SetupUsers);
     if (!settings->childKeys().isEmpty()) {
         settings->beginGroup(accountsC);
         const auto childGroups = selectedAccountIds.isEmpty() ? settings->childGroups() : selectedAccountIds;
+        auto accountsLoaded = false;
         for (const auto &accountId : childGroups) {
             settings->beginGroup(accountId);
             const auto acc = loadAccountHelper(*settings);
@@ -309,12 +346,13 @@ bool AccountManager::restoreFromLegacySettings()
                 continue;
             }
             addAccount(acc);
+            accountsLoaded = true;
+            migrateNetworkSettings(acc, *settings);
             settings->endGroup();
-            moveNetworkSettingsFromGlobalToAccount(acc);
         }
         configFile.cleanupGlobalNetworkConfiguration();
-        ClientProxy().cleanupGlobalNetworkConfiguration();   
-        return true;
+        ClientProxy().cleanupGlobalNetworkConfiguration();
+        return accountsLoaded;
     }
 
     if (wasLegacyImportDialogDisplayed) {
@@ -384,6 +422,7 @@ void AccountManager::saveAccountHelper(const AccountPtr &account, QSettings &set
     settings.setValue(QLatin1String(serverColorC), account->_serverColor);
     settings.setValue(QLatin1String(serverTextColorC), account->_serverTextColor);
     settings.setValue(QLatin1String(serverHasValidSubscriptionC), account->serverHasValidSubscription());
+    settings.setValue(QLatin1String(serverDesktopEnterpriseUpdateChannelC), account->enterpriseUpdateChannel().toString());
     settings.setValue(QLatin1String(encryptionCertificateSha256FingerprintC), account->encryptionCertificateFingerprint());
     if (!account->_skipE2eeMetadataChecksumValidation) {
         settings.remove(QLatin1String(skipE2eeMetadataChecksumValidationC));
@@ -481,30 +520,60 @@ void AccountManager::saveAccountHelper(const AccountPtr &account, QSettings &set
     }
 }
 
-void AccountManager::moveNetworkSettingsFromGlobalToAccount(const AccountPtr &account)
+void AccountManager::migrateNetworkSettings(const AccountPtr &account, const QSettings &settings)
 {
+    // QSettings from old ConfigFile to new ConfigFile to Account
+    auto accountProxyType = settings.value(networkProxyTypeC).value<QNetworkProxy::ProxyType>();
+    auto accountProxyHost = settings.value(networkProxyHostNameC).toString();
+    auto accountProxyPort = settings.value(networkProxyPortC).toInt();
+    auto accountProxyNeedsAuth = settings.value(networkProxyNeedsAuthC).toBool();
+    auto accountProxyUser = settings.value(networkProxyUserC).toString();
+
+    // Override user settings with global settings if user is set to use global settings
     ConfigFile configFile;
-    const auto hostname = configFile.proxyHostName();
-
-    if (!hostname.isEmpty()) {
-        account->setProxySettings(static_cast<QNetworkProxy::ProxyType>(configFile.proxyType()),
-                                  hostname,
-                                  configFile.proxyPort(),
-                                  configFile.proxyNeedsAuth(),
-                                  configFile.proxyUser(),
-                                  configFile.proxyPassword());
+    auto accountProxySetting = settings.value(networkProxySettingC).toInt();
+    if (accountProxySetting == 0 && configFile.isMigrationInProgress()) {
+        accountProxyType = static_cast<QNetworkProxy::ProxyType>(configFile.proxyType());
+        accountProxyHost = configFile.proxyHostName();
+        accountProxyPort = configFile.proxyPort();
+        accountProxyNeedsAuth = configFile.proxyNeedsAuth();
+        accountProxyUser = configFile.proxyUser();
+        qCInfo(lcAccountManager) << "Account is using global settings:" << accountProxyType;
     }
-
-    const auto useUploadLimit = configFile.useUploadLimit();
-    const auto useDownloadLimit = configFile.useDownloadLimit();
-    if (useUploadLimit == 0 && useDownloadLimit == 0) {
-        return;
+    account->setProxyType(accountProxyType);
+    account->setProxyHostName(accountProxyHost);
+    account->setProxyPort(accountProxyPort);
+    account->setProxyNeedsAuth(accountProxyNeedsAuth);
+    account->setProxyUser(accountProxyUser);
+    const auto globalUseUploadLimit = static_cast<Account::AccountNetworkTransferLimitSetting>(configFile.useUploadLimit());
+    const auto globalUseDownloadLimit = static_cast<Account::AccountNetworkTransferLimitSetting>(configFile.useDownloadLimit());
+    // User network settings
+    auto userUseUploadLimit = static_cast<Account::AccountNetworkTransferLimitSetting>(settings.value(networkUploadLimitSettingC, 
+        QVariant::fromValue(account->uploadLimitSetting())).toInt());
+    auto userUploadLimit = settings.value(networkUploadLimitC, account->uploadLimit()).toInt();
+    auto userUseDownloadLimit = static_cast<Account::AccountNetworkTransferLimitSetting>(settings.value(networkDownloadLimitSettingC, 
+        QVariant::fromValue(account->downloadLimitSetting())).toInt());
+    auto userDownloadLimit = settings.value(networkDownloadLimitC, account->downloadLimit()).toInt();
+    if (userUseUploadLimit == Account::AccountNetworkTransferLimitSetting::LegacyGlobalLimit) {
+        userUseUploadLimit = globalUseUploadLimit;
+        userUploadLimit = configFile.uploadLimit();
+        qCDebug(lcAccountManager) << "Overriding upload limit with global setting:" << userUseUploadLimit 
+            << "- upload limit:" << userUploadLimit;
+    }
+    if (userUseDownloadLimit == Account::AccountNetworkTransferLimitSetting::LegacyGlobalLimit) {
+        userUseDownloadLimit = globalUseDownloadLimit;
+        userDownloadLimit = configFile.downloadLimit();
+        qCDebug(lcAccountManager) << "Overriding download limit with global setting" << userUseDownloadLimit 
+            << "- download limit:" << userDownloadLimit;
+    }
+    if (userUseUploadLimit != Account::AccountNetworkTransferLimitSetting::NoLimit) {
+        account->setUploadLimitSetting(userUseUploadLimit);
+        account->setUploadLimit(userUploadLimit);
+    }
+    if (userUseDownloadLimit != Account::AccountNetworkTransferLimitSetting::NoLimit) {
+        account->setDownloadLimitSetting(userUseDownloadLimit);
+        account->setDownloadLimit(userDownloadLimit);
     }
-
-    account->setUploadLimitSetting(static_cast<Account::AccountNetworkTransferLimitSetting>(useUploadLimit));
-    account->setUploadLimit(configFile.uploadLimit());
-    account->setDownloadLimitSetting(static_cast<Account::AccountNetworkTransferLimitSetting>(useDownloadLimit));
-    account->setDownloadLimit(configFile.downloadLimit());
 }
 
 AccountPtr AccountManager::loadAccountHelper(QSettings &settings)
@@ -565,6 +634,9 @@ AccountPtr AccountManager::loadAccountHelper(QSettings &settings)
     acc->_serverVersion = settings.value(QLatin1String(serverVersionC)).toString();
     acc->_serverColor = settings.value(QLatin1String(serverColorC)).value<QColor>();
     acc->_serverTextColor = settings.value(QLatin1String(serverTextColorC)).value<QColor>();
+    acc->_serverHasValidSubscription = settings.value(QLatin1String(serverHasValidSubscriptionC), false).value<bool>();
+    acc->_enterpriseUpdateChannel = UpdateChannel::fromString(
+        settings.value(QLatin1String(serverDesktopEnterpriseUpdateChannelC), QVariant::fromValue(UpdateChannel::Invalid.toString())).toString());
     acc->_skipE2eeMetadataChecksumValidation = settings.value(QLatin1String(skipE2eeMetadataChecksumValidationC), {}).toBool();
     acc->_davUser = settings.value(QLatin1String(davUserC)).toString();
 
@@ -578,13 +650,8 @@ AccountPtr AccountManager::loadAccountHelper(QSettings &settings)
         }
         acc->_settingsMap.insert(key, settings.value(key));
     }
-
     acc->setCredentials(CredentialsFactory::create(authType));
-    acc->setProxyType(settings.value(networkProxyTypeC).value<QNetworkProxy::ProxyType>());
-    acc->setProxyHostName(settings.value(networkProxyHostNameC).toString());
-    acc->setProxyPort(settings.value(networkProxyPortC).toInt());
-    acc->setProxyNeedsAuth(settings.value(networkProxyNeedsAuthC).toBool());
-    acc->setProxyUser(settings.value(networkProxyUserC).toString());
+
     acc->setUploadLimitSetting(
         settings.value(
             networkUploadLimitSettingC,
@@ -595,12 +662,14 @@ AccountPtr AccountManager::loadAccountHelper(QSettings &settings)
             networkDownloadLimitSettingC,
             QVariant::fromValue(Account::AccountNetworkTransferLimitSetting::NoLimit)
         ).value<Account::AccountNetworkTransferLimitSetting>());
-
     acc->setUploadLimit(settings.value(networkUploadLimitC).toInt());
     acc->setDownloadLimit(settings.value(networkDownloadLimitC).toInt());
 
+    ConfigFile configFile;
     const auto proxyPasswordKey = QString(acc->userIdAtHostWithPort() + networkProxyPasswordKeychainKeySuffixC);
-    const auto job = new QKeychain::ReadPasswordJob(Theme::instance()->appName(), this);
+    const auto appName = configFile.isUnbrandedToBrandedMigrationInProgress() ? ConfigFile::unbrandedAppName 
+        : Theme::instance()->appName();
+    const auto job = new QKeychain::ReadPasswordJob(appName, this);
     job->setKey(proxyPasswordKey);
     connect(job, &QKeychain::Job::finished, this, [acc](const QKeychain::Job *const incomingJob) {
         const auto incomingReadJob = qobject_cast<const QKeychain::ReadPasswordJob *>(incomingJob);
@@ -638,7 +707,6 @@ AccountStatePtr AccountManager::account(const QString &name)
 AccountStatePtr AccountManager::accountFromUserId(const QString &id) const
 {
     const auto accountsList = accounts();
-
     for (const auto &account : accountsList) {
         const auto isUserIdWithPort = id.split(QLatin1Char(':')).size() > 1;
         const auto port = isUserIdWithPort ? account->account()->url().port() : -1;
@@ -649,7 +717,6 @@ AccountStatePtr AccountManager::accountFromUserId(const QString &id) const
             return account;
         }
     }
-
     return {};
 }
 
@@ -687,10 +754,9 @@ void AccountManager::deleteAccount(OCC::AccountState *account)
 
     account->account()->deleteAppToken();
 
-    // clean up config from subscriptions if the account removed was the only with valid subscription
-    if (account->account()->serverHasValidSubscription()) {
-        updateServerHasValidSubscriptionConfig();
-    }
+    // clean up config from subscriptions and enterprise channel
+    updateServerHasValidSubscriptionConfig();
+    updateServerDesktopEnterpriseUpdateChannel();
 
     emit accountSyncConnectionRemoved(account);
     emit accountRemoved(account);
@@ -700,15 +766,28 @@ void AccountManager::updateServerHasValidSubscriptionConfig()
 {
     auto serverHasValidSubscription = false;
     for (const auto &account : std::as_const(_accounts)) {
-        if (!account->account()->serverHasValidSubscription()) {
-            continue;
+        if (account->account()->serverHasValidSubscription()) {
+            serverHasValidSubscription = true;
+            break;
         }
-
-        serverHasValidSubscription = true;
-        break;
     }
 
-    ConfigFile().setServerHasValidSubscription(serverHasValidSubscription);
+    if (ConfigFile().serverHasValidSubscription() != serverHasValidSubscription) {
+        ConfigFile().setServerHasValidSubscription(serverHasValidSubscription);
+    }
+}
+
+void AccountManager::updateServerDesktopEnterpriseUpdateChannel()
+{
+    UpdateChannel most_stable_channel = UpdateChannel::Invalid;
+    for (const auto &account : std::as_const(_accounts)) {
+        if (const auto accounts_channel = account->account()->enterpriseUpdateChannel();
+            account->account()->serverHasValidSubscription() && accounts_channel > most_stable_channel) {
+            most_stable_channel = accounts_channel;
+        }
+    }
+
+    ConfigFile().setDesktopEnterpriseChannel(most_stable_channel.toString());
 }
 
 AccountPtr AccountManager::createAccount()
@@ -735,7 +814,7 @@ void AccountManager::shutdown()
 
 QList<AccountStatePtr> AccountManager::accounts() const
 {
-     return _accounts;
+    return _accounts;
 }
 
 bool AccountManager::isAccountIdAvailable(const QString &id) const
@@ -772,17 +851,15 @@ void AccountManager::addAccountState(AccountState *const accountState)
     _accounts << ptr;
     ptr->trySignIn();
 
-    // update config subscriptions if the account added is the only with valid subscription
-    if (accountState->account()->serverHasValidSubscription() && !ConfigFile().serverHasValidSubscription()) {
-        updateServerHasValidSubscriptionConfig();
-    }
+    updateServerHasValidSubscriptionConfig();
+    updateServerDesktopEnterpriseUpdateChannel();
 
     emit accountAdded(accountState);
 }
 
 bool AccountManager::forceLegacyImport() const
 {
-    return _forceLegacyImport;
+   return _forceLegacyImport;
 }
 
 void AccountManager::setForceLegacyImport(const bool forceLegacyImport)
