@@ -1,15 +1,7 @@
 /*
- * Copyright (C) by Duncan Mac-Vicar P. <duncan@kde.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2014 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "folderwizard.h"
@@ -63,11 +55,11 @@ QString FormatWarningsWizardPage::formatWarnings(const QStringList &warnings) co
 {
     QString formattedWarning;
     if (warnings.count() == 1) {
-        formattedWarning = warnings.first();
+        formattedWarning = Utility::escape(warnings.first());
     } else if (warnings.count() > 1) {
         formattedWarning = "<ul>";
         for (const auto &warning : warnings) {
-            formattedWarning += QString::fromLatin1("<li>%1</li>").arg(warning);
+            formattedWarning += QString::fromLatin1("<li>%1</li>").arg(Utility::escape(warning));
         }
         formattedWarning += "</ul>";
     }
@@ -151,7 +143,8 @@ void FolderWizardLocalPath::slotChooseLocalFolder()
 
     QString dir = QFileDialog::getExistingDirectory(this,
         tr("Select the source folder"),
-        sf);
+        sf,
+        QFileDialog::ShowDirsOnly);
     if (!dir.isEmpty()) {
         // set the last directory component name as alias
         _ui.localFolderLineEdit->setText(QDir::toNativeSeparators(dir));
@@ -317,7 +310,7 @@ void FolderWizardRemotePath::recursiveInsert(QTreeWidgetItem *parent, QStringLis
         item->setIcon(0, folderIcon);
         item->setText(0, folderName);
         item->setData(0, Qt::UserRole, folderPath);
-        item->setToolTip(0, folderPath);
+        item->setToolTip(0, Utility::escape(folderPath));
         item->setChildIndicatorPolicy(QTreeWidgetItem::ShowIndicator);
     }
 
@@ -367,7 +360,7 @@ void FolderWizardRemotePath::slotUpdateDirectories(const QStringList &list)
     }
     QStringList sortedList = list;
     Utility::sortFilenames(sortedList);
-    for (auto path : sortedList) {
+    for (auto path : std::as_const(sortedList)) {
         path.remove(webdavFolder);
 
         // Don't allow to select subfolders of encrypted subfolders
@@ -507,7 +500,9 @@ bool FolderWizardRemotePath::isComplete() const
         }
 
         if (targetPath.startsWith(remoteDir)) {
-            showWarn(tr("Please choose a different location. %1 is already being synced to %2.").arg(Utility::escape(targetPath), Utility::escape(localDir)));
+            _ui.warnFrame->show();
+            _ui.warnLabel->hide();
+            _ui.infoLabel->setText(tr("You are already syncing the subfolder %1 at %2.").arg(Utility::escape(targetPath), Utility::escape(localDir)));
             break;
         }
 
@@ -538,6 +533,7 @@ void FolderWizardRemotePath::showWarn(const QString &msg) const
 
     } else {
         _ui.warnFrame->show();
+        _ui.infoLabel->hide();
         _ui.warnLabel->setText(msg);
     }
 }
