@@ -1,15 +1,7 @@
 /*
- * Copyright (C) 2015 by Christian Kamm <kamm@incasoftware.de>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2015 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "proxyauthhandler.h"
@@ -70,8 +62,7 @@ void ProxyAuthHandler::handleProxyAuthenticationRequired(
 
         // If the user explicitly configured the proxy in the
         // network settings, don't ask about it.
-        if ((account && (account->networkProxySetting() == Account::AccountNetworkProxySetting::GlobalProxy
-                         || account->proxyType() == QNetworkProxy::HttpProxy
+        if ((account && (account->proxyType() == QNetworkProxy::HttpProxy
                          || account->proxyType() == QNetworkProxy::Socks5Proxy))
             || _configFile->proxyType() == QNetworkProxy::HttpProxy
             || _configFile->proxyType() == QNetworkProxy::Socks5Proxy) {
