@@ -1,15 +1,7 @@
 /*
- * Copyright (C) by Klaas Freitag <freitag@owncloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2016 ownCloud GmbH
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef ACTIVITYDATA_H
@@ -144,7 +136,7 @@ class Activity
     Q_PROPERTY(QVariantMap subjectRichParameters MEMBER _subjectRichParameters)
 
 public:
-    using Identifier = QPair<qlonglong, QString>;
+    using Identifier = QPair<qint64, QString>;
 
     // Note that these are in the order we want to present them in the model!
     enum Type {
@@ -168,7 +160,7 @@ public:
     using TalkNotificationData = OCC::TalkNotificationData;
 
     Type _type;
-    qlonglong _id = 0LL;
+    qint64 _id = 0LL;
     QString _fileAction;
     int _objectId = 0;
     TalkNotificationData _talkNotificationData;
