@@ -17,6 +17,7 @@
 #include "caseclashfilenamedialog.h"
 #include "activitydata.h"
 #include "systray.h"
+#include "common/utility.h"
 
 #include <QtCore>
 #include <QAbstractListModel>
@@ -26,6 +27,8 @@
 #include <QJsonDocument>
 #include <QLoggingCategory>
 
+using namespace Qt::StringLiterals;
+
 namespace OCC {
 
 Q_LOGGING_CATEGORY(lcActivity, "nextcloud.gui.activity", QtInfoMsg)
@@ -192,7 +195,7 @@ QVariant ActivityListModel::data(const QModelIndex &index, int role) const
 
     const auto displayLocation = [&]() {
         const auto displayPath = QFileInfo(getDisplayPath()).path();
-        return displayPath == "." || displayPath == "/" ? QString() : displayPath;
+        return displayPath == "." || displayPath == "/" ? QString() : Utility::escape(displayPath);
     };
 
     const auto generatePreviewMap = [](const PreviewData &preview) {
@@ -504,7 +507,7 @@ void ActivityListModel::insertOrRemoveDummyFetchingActivity()
 
 void ActivityListModel::activitiesReceived(const QJsonDocument &json, int statusCode)
 {
-    const auto activities = json.object().value(QStringLiteral("ocs")).toObject().value(QStringLiteral("data")).toArray();
+    const auto activities = json.object().value("ocs"_L1).toObject().value("data"_L1).toArray();
 
     if (!_accountState) {
         return;
