@@ -23,6 +23,7 @@
 #include "tray/unifiedsearchresultslistmodel.h"
 #include "tray/talkreply.h"
 #include "userstatusconnector.h"
+#include "common/utility.h"
 
 #include <QtCore>
 #include <QDesktopServices>
@@ -428,7 +429,7 @@ void User::slotRefresh()
     
     if (checkPushNotificationsAreReady()) {
         // we are relying on WebSocket push notifications - ignore refresh attempts from UI
-        slotRefreshActivitiesInitial();
+        slotRefreshActivities();
         _timeSinceLastCheck[_account.data()].invalidate();
         return;
     }
@@ -445,7 +446,7 @@ void User::slotRefresh()
         return;
     }
     if (_account.data() && _account.data()->isConnected()) {
-        slotRefreshActivitiesInitial();
+        slotRefreshActivities();
         slotRefreshNotifications();
         timer.start();
     }
@@ -588,7 +589,7 @@ void User::slotProgressInfo(const QString &folder, const ProgressInfo &progress)
             return;
         const auto &engine = f->syncEngine();
         const auto style = engine.lastLocalDiscoveryStyle();
-        for (const auto &activity : _activityModel->errorsList()) {
+        for (const auto errorsList = _activityModel->errorsList(); const auto &activity : errorsList) {
             if (activity._expireAtMsecs != -1) {
                 // we process expired activities in a different slot
                 continue;
@@ -602,24 +603,7 @@ void User::slotProgressInfo(const QString &folder, const ProgressInfo &progress)
                 continue;
             }
 
-            if (activity._syncFileItemStatus == SyncFileItem::Conflict && !FileSystem::fileExists(f->path() + activity._file)) {
-                _activityModel->removeActivityFromActivityList(activity);
-                continue;
-            }
-
-            if (activity._syncFileItemStatus == SyncFileItem::FileLocked && !FileSystem::fileExists(f->path() + activity._file)) {
-                _activityModel->removeActivityFromActivityList(activity);
-                continue;
-            }
-
-
-            if (activity._syncFileItemStatus == SyncFileItem::FileIgnored && !FileSystem::fileExists(f->path() + activity._file)) {
-                _activityModel->removeActivityFromActivityList(activity);
-                continue;
-            }
-
-
-            if (!FileSystem::fileExists(f->path() + activity._file)) {
+            if (const auto filePath = f->path() + activity._file; !FileSystem::fileExists(filePath)) {
                 _activityModel->removeActivityFromActivityList(activity);
                 continue;
             }
@@ -1555,7 +1539,7 @@ void UserModel::removeAccount(const int id)
                            tr("Confirm Account Removal"),
                            tr("<p>Do you really want to remove the connection to the account <i>%1</i>?</p>"
                               "<p><b>Note:</b> This will <b>not</b> delete any files.</p>")
-                               .arg(_users[id]->name()),
+                               .arg(Utility::escape(_users[id]->name())),
                            QMessageBox::NoButton);
     const auto * const yesButton = messageBox.addButton(tr("Remove connection"), QMessageBox::YesRole);
     messageBox.addButton(tr("Cancel"), QMessageBox::NoRole);
