@@ -37,6 +37,13 @@ public:
     static QString printQNetworkProxy(const QNetworkProxy &proxy);
     static const char *proxyTypeToCStr(QNetworkProxy::ProxyType type);
 
+    static constexpr char proxyTypeC[] = "Proxy/type";
+    static constexpr char proxyHostC[] = "Proxy/host";
+    static constexpr char proxyPortC[] = "Proxy/port";
+    static constexpr char proxyUserC[] = "Proxy/user";
+    static constexpr char proxyPassC[] = "Proxy/pass";
+    static constexpr char proxyNeedsAuthC[] = "Proxy/needsAuth";
+
 public slots:
     void setupQtProxyFromConfig();
     void saveProxyConfigurationFromSettings(const QSettings &settings);
