@@ -1,15 +1,6 @@
 /*
- * Copyright (C) by Kevin Ottens <kevin.ottens@nextcloud.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- * for more details.
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 #pragma once
 
@@ -43,6 +34,8 @@ public:
 
     explicit HydrationJob(QObject *parent = nullptr);
 
+    ~HydrationJob() override;
+
     AccountPtr account() const;
     void setAccount(const AccountPtr &account);
 
@@ -68,7 +61,7 @@ public:
     void setE2eMangledName(const QString &e2eMangledName);
 
     qint64 fileTotalSize() const;
-    void setFileTotalSize(qint64 totalSize);
+    void setFileTotalSize(qint64 fileTotalSize);
 
     Status status() const;
 
@@ -109,6 +102,7 @@ private:
 
     bool _isEncryptedFile = false;
     QString _e2eMangledName;
+    qint64 _fileTotalSize = 0;
 
     QLocalServer *_transferDataServer = nullptr;
     QLocalServer *_signalServer = nullptr;
